@@ -38,8 +38,10 @@
 static char rcsid[] = "$OpenBSD: daemon.c,v 1.2 1996/08/19 08:22:13 tholo Exp $";
 #endif /* LIBC_SCCS and not lint */
 
+#include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 #ifdef HAVE_PATHS_H
 # include <paths.h>
@@ -52,13 +54,14 @@ daemon(int nochdir, int noclose)
 {
 	int fd;
 
-	switch (fork()) {
+	switch(fork()) {
 	case -1:
+		error_fatal("failed to fork()", errno);
 		return (-1);
 	case 0:
 		break;
 	default:
-		_exit(0);
+		_exit(EXIT_SUCCESS);
 	}
 
 	if (setsid() == -1)
@@ -78,4 +81,3 @@ daemon(int nochdir, int noclose)
 }
 
 #endif /* !HAVE_DAEMON */
-
