@@ -50,6 +50,7 @@
  **************************************************************/
 
 #include <ctype.h>
+#include <string.h>
 
 #include "prngd.h"
 
@@ -261,6 +262,7 @@ dopr(char *buffer, size_t maxlen, const char *format, va_list args)
 							value = va_arg(args, unsigned int);
 						fmtint (buffer, &currlen, maxlen, value, 10, min, max, flags);
 						break;
+					/*FALLTHROUGH*/
 					case 'X':
 						flags |= DP_F_UP;
 					case 'x':
@@ -283,6 +285,7 @@ dopr(char *buffer, size_t maxlen, const char *format, va_list args)
 						/* um, floating point? */
 						fmtfp(buffer, &currlen, maxlen, fvalue, min, max, flags);
 						break;
+					/*FALLTHROUGH*/
 					case 'E':
 						flags |= DP_F_UP;
 					case 'e':
@@ -291,6 +294,7 @@ dopr(char *buffer, size_t maxlen, const char *format, va_list args)
 						else
 							fvalue = va_arg(args, double);
 						break;
+					/*FALLTHROUGH*/
 					case 'G':
 						flags |= DP_F_UP;
 					case 'g':
@@ -316,7 +320,7 @@ dopr(char *buffer, size_t maxlen, const char *format, va_list args)
 						if (cflags == DP_C_SHORT) {
 							short int *num;
 							num = va_arg(args, short int *);
-							*num = currlen;
+							*num = (short)currlen;
 						} else if (cflags == DP_C_LONG) {
 							long int *num;
 							num = va_arg(args, long int *);
