@@ -169,6 +169,22 @@ int getrusage(int who, struct rusage *rusage);
 #define PATH_SYSLOG     "/private/var/log/system.log"
 #endif
 
+#ifdef FREEBSD
+#define HAVE_GETRUSAGE
+/* not yet supported */
+#define O_RSYNC	0
+#ifndef O_SYNC
+#define O_SYNC	O_FSYNC
+#define PATH_TMP        "/tmp"
+#define PATH_VAR_TMP    "/var/tmp"
+#define PATH_PASSWD     "/etc/passwd"
+#define PATH_WTMP       "/var/log/wtmp"
+#define PATH_UTMP       "/var/run/utmp"
+#define PATH_SYSLOG     "/var/log/messages"
+#endif
+
+#endif
+
 #ifdef NEXTSTEP
 #define HAVE_GETRUSAGE
 /* not supported */
@@ -252,6 +268,17 @@ extern void closelog();
 #define PATH_MAILLOG	"/var/spool/mqueue/syslog"
 #endif
 
+#ifdef AIX51
+#define HAVE_GETRUSAGE
+#define SOCKLEN_T     socklen_t
+#define PATH_TMP      "/tmp"
+#define PATH_VAR_TMP  "/var/tmp"
+#define PATH_PASSWD   "/etc/passwd"
+#define PATH_WTMP     "/var/adm/wtmp"
+#define PATH_UTMP     "/etc/utmp"
+#define PATH_SYSLOG   "/var/log/messages"
+#endif
+
 #if defined(ULTRIX)
 typedef int     ssize_t;
 extern void closelog(void);
@@ -423,6 +450,9 @@ extern closelog(void);
 #define O_RSYNC         0
 #define SA_RESTART      0
 #define IS_UNIX_SOCKET(m)  (S_ISSOCK(m) || S_ISFIFO(m))
+#ifdef HAVE_FLOSS_H
+#include <floss.h>
+#endif
 #endif
 
 #ifndef RANDSAVENAME
