@@ -6,6 +6,10 @@
 
 #include "prngd.h"
 
+#ifdef NEED_SYS_SELECT_H
+#include <sys/select.h>
+#endif /* NEED_SYS_SELECT_H */
+
 /*
  * Try to obtain the maximum allowed number of open files.
  * Compare with FD_SETSIZE and return whatever is smaller.
@@ -25,8 +29,10 @@ int obtain_limit(void)
 #endif
 
 #ifdef RLIMIT_NOFILE
-    if (getrlimit(RLIMIT_NOFILE, &rl) < 0)
+    if (getrlimit(RLIMIT_NOFILE, &rl) < 0) {
+	error_error("getrlimit() failed", errno);
         return (-1);
+    }
     limit = rl.rlim_cur;
 #endif
 
