@@ -90,7 +90,11 @@ void rand_add(const void *buf, int num, double add)
   unsigned char temp_md[SHA_DIGEST_LENGTH];
   SHA1_CTX c;
 
-  assert(pool != NULL);
+  /* be absolutely sure that the pool array has been allocated */
+  if (pool == NULL) {
+  	error_fatal("In rand.c pool has not been allocated", 0);
+	exit(EXIT_FAILURE);
+  }
 
   /*
    * Mix new bytes into the pool. To perform this operation, read
@@ -131,8 +135,8 @@ void rand_add(const void *buf, int num, double add)
       rand_flip_bits();		/* when wrapped, flip once */
   }
 
-  memset(temp_md, 0, SHA_DIGEST_LENGTH);
-  memset(&c, 0, sizeof(c));
+  (void)memset(temp_md, 0, SHA_DIGEST_LENGTH);
+  (void)memset(&c, 0, sizeof(c));
 
   /*
    * Register the weighted entropy, but of course there cannot be more
@@ -240,7 +244,7 @@ int rand_bytes(unsigned char *buf, int num)
       pool[position + j] ^= temp_md[j];
     position += SHA_DIGEST_LENGTH;
     position %= pool_size;	/* wrap, if needed */
-    for (j = i; j < num; j++)
+    for (j = i; (j < num) && (j - i < SHA_DIGEST_LENGTH); j++)
       buf[j] = temp_md[j - i];
   }
 
@@ -276,8 +280,8 @@ int rand_bytes(unsigned char *buf, int num)
       rand_flip_bits();		/* when wrapped, flip once */
   }
 
-  memset(&c, 0, sizeof(c));
-  memset(temp_md, 0, SHA_DIGEST_LENGTH);
+  (void)memset(&c, 0, sizeof(c));
+  (void)memset(temp_md, 0, SHA_DIGEST_LENGTH);
 
   /*
    * When entropy was retrieved, reduce the "entropy counter". Do not go
@@ -298,13 +302,14 @@ int rand_pool(void)
   * enough entropy is available yet, return "0" to flag that a call to
   * rand_bytes() would fail.
   */
+
   if (!pool_seeded)
     return 0;
   else
-    return entropy * BITS_PER_BYTE;
+    return (int)(entropy * BITS_PER_BYTE);
 }
 
-int rand_init(int set_pool_size, int set_entropy_needed)
+void rand_init(int set_pool_size, int set_entropy_needed)
 {
   /*
    * Set the pool size. For simplicity (we must be able to walk back and
@@ -317,12 +322,10 @@ int rand_init(int set_pool_size, int set_entropy_needed)
     pool_size = 100;
   if (pool_size % SHA_DIGEST_LENGTH)
     pool_size = (pool_size / SHA_DIGEST_LENGTH + 1) * SHA_DIGEST_LENGTH;
-  pool = malloc(pool_size);
+  pool = my_malloc(pool_size);
 
   /*
    * Remember the minimum seed needed.
    */
   entropy_needed = set_entropy_needed;
-
-  return (pool != NULL);
 }
