@@ -2,8 +2,10 @@
   * Internal seed functions
   */
 
+#include <errno.h>
 #include <unistd.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -44,6 +46,7 @@ NULL};
   * - getpid() is probably not too hard to guess, but well, it won't hurt.
   * - getrusage(), if available, contains several statistical data that might
   *   be hard to guess.
+  * - seed_counter is a simple counter to mix in...
   * This function is especially designed to be computationally cheap, so that
   * it can be called very often, especially every time when an event occurs
   * (a connection is opened etc), so that the usage of the real time values
@@ -57,18 +60,27 @@ NULL};
 void seed_internal(seed_t *seed_p)
 {
   seed_t seed, *my_seed_p;
+  static int seed_counter = 0;
 
   if (seed_p)
     my_seed_p = seed_p;
   else
     my_seed_p = &seed;
 
-  times(&(my_seed_p->tmsbuf));
-  gettimeofday(&(my_seed_p->tp), NULL);
+  (void)times(&(my_seed_p->tmsbuf));
+  my_gettimeofday(&(my_seed_p->tp), NULL);
   my_seed_p->pid = getpid();
 #ifdef HAVE_GETRUSAGE
-  getrusage(RUSAGE_SELF, &(my_seed_p->usage));
+  (void)getrusage(RUSAGE_SELF, &(my_seed_p->usage));
 #endif
+  /*
+   * add in just a little more variability each time we seed
+   * internally by using a counter.
+   */
+  if (seed_counter == 0)
+    seed_counter = (int)getpid();
+  my_seed_p->seed_counter = seed_counter++;
+
   if (!seed_p)
     rand_add(my_seed_p, sizeof(seed_t), 0.0);
 }
