@@ -57,12 +57,13 @@ static void termination_handler(int received_signal)
     (void)fprintf(stderr, "Caught SIGTERM, shutting down\n");
   close_seedfile();
   if (pidfile) {
-    if (remove(pidfile))
+    if (remove(pidfile) == -1) {
       (void)snprintf(msg_buf, sizeof(msg_buf), "Could not remove pidfile %s",
 		     pidfile);
       msg_buf[sizeof(msg_buf) - 1] = '\0';
       error_error(msg_buf, errno);
       exit(EXIT_FAILURE);
+    }
   }
   exit(EXIT_SUCCESS);
 }
@@ -73,7 +74,7 @@ static void sighup_handler(int received_signal)
 
   if (received_signal != SIGHUP) {
     (void)snprintf(msg_buf, sizeof(msg_buf),
-	"Termination handler called with wrong signal: %d != SIGHUP",
+	"HUP handler called with wrong signal: %d != SIGHUP",
 	received_signal);
     msg_buf[sizeof(msg_buf) - 1] = '\0';
     error_notice(msg_buf, 0);
@@ -87,7 +88,7 @@ static void child_handler(int received_signal)
 
   if (received_signal != SIGCHLD) {
     (void)snprintf(msg_buf, sizeof(msg_buf),
-	"Termination handler called with wrong signal: %d != SIGCHLD",
+	"Sigchild handler called with wrong signal: %d != SIGCHLD",
 	received_signal);
     msg_buf[sizeof(msg_buf) - 1] = '\0';
     error_notice(msg_buf, 0);
@@ -115,7 +116,7 @@ static void collect_children(pid_t *gatherer_pid)
   int gatherer_status;
 
   while (((child_pid = waitpid(-1, &gatherer_status, WNOHANG)) > 0)
-	 || (errno == EINTR)) {
+	 || ((child_pid < 0) && (errno == EINTR))) {
     if (child_pid > 0) {
       rand_add(&gatherer_status, sizeof(gatherer_status), 0.0);
       if (WIFEXITED(gatherer_status) || WIFSIGNALED(gatherer_status)) {
@@ -448,10 +449,6 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
       /*
        * time to call another gatherer 
        */
-      if (my_pipe(pipedes) < 0)
-	continue;		/*
-				 * We cannot do anything about it 
-				 */
 
       /*
        * Select the next gatherer to be used
@@ -462,6 +459,11 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
         continue;
       }
 
+      if (my_pipe(pipedes) < 0)
+	continue;		/*
+				 * We cannot do anything about it 
+				 */
+
       est = entropy_source[gatherer_entry].rate; /* for later use */
       gatherer_bytes = 0;
 
@@ -493,11 +495,16 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
 		(void)snprintf(msg_buf, sizeof(msg_buf),
 			"Failed to execl(%s, %s, %s, %s, %s, %s)",
 			entropy_source[gatherer_entry].path,
-			entropy_source[gatherer_entry].args[0],
-			entropy_source[gatherer_entry].args[1],
-			entropy_source[gatherer_entry].args[2],
-			entropy_source[gatherer_entry].args[3],
-			entropy_source[gatherer_entry].args[4]);
+			entropy_source[gatherer_entry].args[0] ?
+			entropy_source[gatherer_entry].args[0] : "",
+			entropy_source[gatherer_entry].args[1] ?
+			entropy_source[gatherer_entry].args[1] : "",
+			entropy_source[gatherer_entry].args[2] ?
+			entropy_source[gatherer_entry].args[2] : "",
+			entropy_source[gatherer_entry].args[3] ?
+			entropy_source[gatherer_entry].args[3] : "",
+			entropy_source[gatherer_entry].args[4] ?
+			entropy_source[gatherer_entry].args[4] : "");
 		msg_buf[sizeof(msg_buf) - 1] = '\0';
 		error_fatal(msg_buf, errno);
 		_exit(EXIT_FAILURE);
