@@ -25,6 +25,10 @@ ssize_t socket_read(int fildes, void *buf, size_t nbyte)
     else if (errno == EWOULDBLOCK)
       continue;
 #endif
+    else if (retval == -1) {
+      error_error("read() in socket_read() failed", errno);
+      break;
+    }
     else
       break;
   }
@@ -48,6 +52,14 @@ ssize_t socket_write(int fildes, void *buf, size_t nbyte)
     else if (errno == EWOULDBLOCK)
       continue;
 #endif
+    else if (errno == EPIPE) {
+      error_notice("write() in socket_write() failed", errno);
+      break;
+    }
+    else if (retval == -1) {
+      error_error("write() in socket_write() failed", errno);
+      break;
+    }
     else
       break;
   }
